=== modified file 'multiparent/__init__.py'
--- multiparent/__init__.py	2007-04-11 20:03:40 +0000
+++ multiparent/__init__.py	2007-04-11 20:39:57 +0000
@@ -84,6 +84,31 @@
             for line in hunk.to_patch():
                 yield line
 
+    @staticmethod
+    def from_patch(lines):
+        line_iter = iter(lines)
+        hunks = []
+        cur_line = None
+        while(True):
+            try:
+                cur_line = line_iter.next()
+            except StopIteration:
+                break
+            if cur_line[0] == 'i':
+                num_lines = int(cur_line.split(' ')[1])
+                hunk_lines = [line_iter.next() for x in xrange(num_lines)]
+                hunk_lines[-1] = hunk_lines[-1][:-1]
+                hunks.append(NewText(hunk_lines))
+            elif cur_line[0] == '\n':
+                hunks[-1].lines[-1] += '\n'
+            else:
+                assert cur_line[0] == 'c', cur_line[0]
+                parent, parent_pos, child_pos, num_lines =\
+                    [int(v) for v in cur_line.split(' ')[1:]]
+                hunks.append(ParentText(parent, parent_pos, child_pos,
+                                        num_lines))
+        return MultiParent(hunks)
+
     def range_iterator(self):
         """Iterate through the hunks, with range indicated
 

=== modified file 'multiparent/tests/test_multiparent.py'
--- multiparent/tests/test_multiparent.py	2007-04-11 04:18:39 +0000
+++ multiparent/tests/test_multiparent.py	2007-04-11 20:39:57 +0000
@@ -60,6 +60,18 @@
             list(multiparent.MultiParent([multiparent.NewText(['a\n']),
             multiparent.ParentText(0, 1, 2, 3)]).to_patch()))
 
+    def test_from_patch(self):
+        self.assertEqual(multiparent.MultiParent(
+            [multiparent.NewText(['a\n']),
+             multiparent.ParentText(0, 1, 2, 3)]),
+             multiparent.MultiParent.from_patch(
+             ['i 1\n', 'a\n', '\n', 'c 0 1 2 3\n']))
+        self.assertEqual(multiparent.MultiParent(
+            [multiparent.NewText(['a']),
+             multiparent.ParentText(0, 1, 2, 3)]),
+             multiparent.MultiParent.from_patch(
+             ['i 1\n', 'a\n', 'c 0 1 2 3\n']))
+
     def test_num_lines(self):
         mp = multiparent.MultiParent([multiparent.NewText(['a\n'])])
         self.assertEqual(1, mp.num_lines())

